Struct openml::SupervisedClassification [−][src]
pub struct SupervisedClassification { /* fields omitted */ }Classification task
Methods
impl SupervisedClassification[src]
impl SupervisedClassificationimpl SupervisedClassification[src]
impl SupervisedClassificationpub fn from_openml<'a, T: Id>(id: T) -> StdResult<Self, Error>[src]
pub fn from_openml<'a, T: Id>(id: T) -> StdResult<Self, Error>impl SupervisedClassification[src]
impl SupervisedClassificationpub fn id(&self) -> &str[src]
pub fn id(&self) -> &strget task ID
pub fn name(&self) -> &str[src]
pub fn name(&self) -> &strget task name
pub fn run_static<X, Y, F, M>(&self, flow: F) -> M where
F: Fn(&mut Iterator<Item = (&X, &Y)>, &mut Iterator<Item = &X>) -> Box<Iterator<Item = Y>>,
X: DeserializeOwned,
Y: DeserializeOwned,
M: MeasureAccumulator<Y>, [src]
pub fn run_static<X, Y, F, M>(&self, flow: F) -> M where
F: Fn(&mut Iterator<Item = (&X, &Y)>, &mut Iterator<Item = &X>) -> Box<Iterator<Item = Y>>,
X: DeserializeOwned,
Y: DeserializeOwned,
M: MeasureAccumulator<Y>, run task, specifying the type of an entire feature column in X. This allows to run
machine learning models that take features of different types, or named features in form
of structs.
pub fn run<X, Y, F, M>(&self, flow: F) -> M where
F: Fn(&mut Iterator<Item = (&[X], &Y)>, &mut Iterator<Item = &[X]>) -> Box<Iterator<Item = Y>>,
X: DeserializeOwned,
Y: DeserializeOwned,
M: MeasureAccumulator<Y>, [src]
pub fn run<X, Y, F, M>(&self, flow: F) -> M where
F: Fn(&mut Iterator<Item = (&[X], &Y)>, &mut Iterator<Item = &[X]>) -> Box<Iterator<Item = Y>>,
X: DeserializeOwned,
Y: DeserializeOwned,
M: MeasureAccumulator<Y>, run task, specifying the feature type in X. This allows to run machine learning models
that expect every feature to have the same type.